@@ -1,7 +1,8 @@
 package Mojolicious::Plugin::UniqueTagHelpers;
 use Mojo::Base 'Mojolicious::Plugin';
+use Mojo::Util 'md5_sum';
 
-our $VERSION = '0.05';
+our $VERSION = '1.0';
 
 sub _block { ref $_[0] eq 'CODE' ? $_[0]() : $_[0] }
 
@@ -15,7 +16,7 @@ sub register {
         my $hash = $c->stash->{'uniquetaghelpers.stylesheet'} ||= {};
         if( defined $content ) {
             $hash->{$name} ||= {};
-            my $key = _block $content;
+            my $key = md5_sum( _block($content) // '' );
 
             return $c->content( $name ) if exists $hash->{$name}{$key};
             $hash->{$name}{$key} = 1;
@@ -28,7 +29,7 @@ sub register {
     $app->helper(javascript_for => sub {
         my ($c, $name, $content) = @_;
         $name ||= 'content';
-        my $key = _block $content;
+        my $key = md5_sum( _block($content) // '' );
 
         my $hash = $c->stash->{'uniquetaghelpers.javascript'} ||= {};
         if( defined $content ) {
@@ -41,6 +42,23 @@ sub register {
         }
         return $c->content( $name );
     });
+
+    $app->helper(unique_for => sub {
+        my ($c, $name, $content) = @_;
+        $name ||= 'content';
+        my $key = md5_sum( _block($content) // '' );
+
+        my $hash = $c->stash->{'uniquetaghelpers.unique'} ||= {};
+        if( defined $content ) {
+            $hash->{$name} ||= {};
+
+            return $c->content( $name ) if exists $hash->{$name}{$key};
+            $hash->{$name}{$key} = 1;
+
+            $c->content_for( $name => $content );
+        }
+        return $c->content( $name );
+    });
 }
 
 1;
@@ -85,7 +103,7 @@ javascript and stylesheet allowing multiple include in templates.
     <html>
         <head>
             <title>MyApp</title>
-            %= stylesheet_for 'header';
+            %= content_for 'header';
         </head>
         <body>
             <%= content %>
@@ -124,7 +142,7 @@ This example generate only one link to F<css/main.css>:
         </head>
         <body>
             <%= content %>
-            %= javascript_for 'footer';
+            %= content_for 'footer';
         </body>
     </html
 
@@ -140,6 +158,44 @@ This example generate only one link to F<js/main.js>:
         </body>
     </html>
 
+=head2 unique_for
+
+    @@ index.html.ep
+    % layout 'default';
+    % unique_for 'footer' => begin;
+        <div id="modal">...</div>
+    % end
+
+    ...
+
+    % unique_for 'footer' => begin;
+        <div id="modal">...</div>
+    % end
+
+    @@ layouts/default.html.ep
+    <!DOCTYPE html>
+    <html>
+        <head>
+            <title>MyApp</title>
+        </head>
+        <body>
+            <%= content %>
+            %= content_for 'footer';
+        </body>
+    </html
+
+This example generate only one "modal" element:
+
+    <!DOCTYPE html>
+    <html>
+        <head>
+            <title>MyApp</title>
+        </head>
+        <body>
+            <div id="modal">...</div>
+        </body>
+    </html>
+
 =head1 SEE ALSO
 
 L<Mojolicious>, L<Mojolicious::Guides>, L<Mojolicious::Plugin::TagHelpers>,
